@@ -4,6 +4,7 @@
 
 #include "appeventlistener.hpp"
 #include "quickwidgetsettings.hpp"
+#include "quickwidget.hpp"
 
 static AppEventListener *_instance = NULL;
 
@@ -19,14 +20,17 @@ AppEventListener::AppEventListener(QObject *parent) :
     QObject(parent)
 {
     // Connect to the QtSingleApplication's event
-    QObject::connect(QtSingleApplication::instance(), SIGNAL(messageReceived(const QString&)), this, SLOT(receiveMessage(const QString&)));
+    QObject::connect(QtSingleApplication::instance(), SIGNAL(messageReceived(const QString&)), 
+		     this, SLOT(receiveMessage(const QString&)));
 }
 
 void AppEventListener::receiveMessage(const QString& message)
 {
-    if (message == APP_MESSAGE_ADDWIDGET)
+    if (message.endsWith(".qml")) {
+      QuickWidget::createAndShowNew(message);
+      
+    } else if (message == APP_MESSAGE_SETWIDGET)
     {
-        qDebug() << "TTTTTTEEEEST";
         QuickWidgetSettings settings;
         settings.exec();
     }
