@@ -3,7 +3,7 @@
 
 #include <QObject>
 
-#define APP_MESSAGE_ADDWIDGET "Add widget"
+#define APP_MESSAGE_SETWIDGET "Add widget"
 #define APP_MESSAGE_CLOSE "Close"
 
 class AppEventListener : public QObject
